@@ -33,7 +33,7 @@ import random
 
 from docopt import docopt
 
-__version__ = '0.3.1'
+__version__ = '0.3.2'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -264,21 +264,30 @@ class Config(dict):
         for key in d.keys():
             self[key] = d[key]
 
-# cfg and config_registry are global variables that may be mutated by a
+# _cfg and _config_registry are global variables that may be mutated by a
 # .konchrc file
-cfg = Config()
-config_registry = {
-    'default': cfg
+_cfg = Config()
+_config_registry = {
+    'default': _cfg
 }
 
 
-def start(context, banner=None, shell=AutoShell, *args, **kwargs):
-    """Start up the konch shell with a given context."""
+def start(context=None, banner=None, shell=AutoShell,
+        prompt=None, output=None):
+    """Start up the konch shell. Takes the same parameters as Shell.__init__.
+    """
     logger.debug('Using shell...')
     logger.debug(shell)
     if banner is None:
         banner = speak()
-    shell(context, banner, *args, **kwargs).start()
+    # Default to global config
+    context_ = context or _cfg['context']
+    banner_ = banner or _cfg['banner']
+    shell_ = shell or _cfg['shell']
+    prompt_ = prompt or _cfg['prompt']
+    output_ = output or _cfg['output']
+    shell_(context=context_, banner=banner_,
+        prompt=prompt_, output=output_).start()
 
 
 def config(config_dict):
@@ -289,21 +298,21 @@ def config(config_dict):
         'shell' (default shell class to use).
     """
     logger.debug('Updating with {0}'.format(config_dict))
-    cfg.update(config_dict)
-    return cfg
+    _cfg.update(config_dict)
+    return _cfg
 
 
 def named_config(name, config_dict):
     """Adds a named config to the config registry.
     This function should be called in a .konchrc file.
     """
-    config_registry[name] = Config(**config_dict)
+    _config_registry[name] = Config(**config_dict)
 
 
 def reset_config():
-    global cfg
-    cfg = Config()
-    return cfg
+    global _cfg
+    _cfg = Config()
+    return _cfg
 
 
 def get_file_directory(filename):
@@ -320,7 +329,7 @@ def __ensure_directory_in_path(filename):
 
 
 def use_file(filename):
-    # First update cfg by executing the config file
+    # First update _cfg by executing the config file
     config_file = filename or resolve_path(DEFAULT_CONFIG_FILE)
     if config_file and os.path.exists(config_file):
         logger.info('Using {0}'.format(config_file))
@@ -332,7 +341,7 @@ def use_file(filename):
             warnings.warn('No config file found.')
         else:
             warnings.warn('"{fname}" not found.'.format(fname=config_file))
-    return cfg
+    return _cfg
 
 
 def __get_home_directory():
@@ -367,9 +376,16 @@ def init_config(config_file=None):
         sys.exit(1)
 
 
+def parse_args():
+    """Exposes the docopt command-line arguments parser.
+    Return a dictionary of arguments.
+    """
+    return docopt(__doc__, version=__version__)
+
+
 def main():
     """Main entry point for the konch CLI."""
-    args = docopt(__doc__, version=__version__)
+    args = parse_args()
     if args['--debug']:
         logging.basicConfig(
             format='%(levelname)s %(filename)s: %(message)s',
@@ -382,11 +398,11 @@ def main():
     use_file(args['--file'])
 
     if args['--name']:
-        config_dict = config_registry.get(args['--name'], cfg)
+        config_dict = _config_registry.get(args['--name'], _cfg)
         logger.debug('Using named config...')
         logger.debug(config)
     else:
-        config_dict = cfg
+        config_dict = _cfg
     # Allow default shell to be overriden by command-line argument
     shell_name = args['--shell']
     if shell_name:
